Administration Guide
====================

This guide covers the configuration and administration of **Crossbar.io**.

.. toctree::
   :maxdepth: 2
   :caption: Concepts

   ../Basic-Concepts

.. toctree::
   :maxdepth: 2
   :caption: Node Configuration

   ../Node-Configuration
   ../Node-Configuration-Example
   ../Processes
   ../Controller-Configuration

.. toctree::
   :maxdepth: 2
   :caption: Router Configuration

   ../Router-Configuration
   ../Router-Realms
   ../Router-Components
   ../Proxy-Workers

.. toctree::
   :maxdepth: 2
   :caption: Worker Configuration

   ../Container-Configuration
   ../Guest-Configuration
   ../Native-Worker-Options
   ../Process-Environments

.. toctree::
   :maxdepth: 2
   :caption: Transports

   ../Router-Transports
   ../Transport-Endpoints
   ../WebSocket-Transport
   ../WebSocket-Options
   ../WebSocket-Compression
   ../RawSocket-Transport
   ../Flash-Policy-Transport
   ../Web-Transport-and-Services

.. toctree::
   :maxdepth: 2
   :caption: Web Services

   ../Web-Services
   ../Static-Web-Service
   ../Web-Redirection-Service
   ../JSON-Value-Service
   ../Node-Info-Service
   ../CGI-Script-Service
   ../WSGI-Host-Service
   ../Reverse-Proxy-Service
   ../WebSocket-Service
   ../Long-Poll-Service
   ../Path-Service
   ../Resource-Service
   ../File-Upload-Service
   ../Web-Archive-Service

.. toctree::
   :maxdepth: 2
   :caption: HTTP Bridge

   ../HTTP-Bridge
   ../HTTP-Bridge-Publisher
   ../HTTP-Bridge-Subscriber
   ../HTTP-Bridge-Caller
   ../HTTP-Bridge-Callee
   ../HTTP-Bridge-Webhook

.. toctree::
   :maxdepth: 2
   :caption: Authentication

   ../Authentication
   ../Anonymous-Authentication
   ../Ticket-Authentication
   ../Challenge-Response-Authentication
   ../SCRAM-Authentication
   ../Cryptosign-Authentication
   ../Cookie-Authentication
   ../TLS-Client-Certificate-Authentication
   ../Dynamic-Authenticators

.. toctree::
   :maxdepth: 2
   :caption: Authorization

   ../Authorization

.. toctree::
   :maxdepth: 2
   :caption: Security

   ../Secure-WebSocket-and-HTTPS
   ../TLS-Certificates
   ../SSL-TLS-Interception-Proxies
   ../Cookie-Tracking

.. toctree::
   :maxdepth: 2
   :caption: MQTT

   ../MQTT-Broker

.. toctree::
   :maxdepth: 2
   :caption: Operations

   ../Command-Line
   ../Logging
   ../Going-to-Production
   ../Automatic-Startup-and-Restart
   ../Running-on-privileged-ports
   ../Scaling-Crossbar.io
   ../Network-Tuning
   ../Reverse-Proxies

.. toctree::
   :maxdepth: 2
   :caption: Deployment

   ../Installation-on-Linux
   ../Installation-on-Mac-OS-X
   ../Installation-on-Windows
   ../Creating-Docker-Images
   ../Setup-on-Amazon-EC2
   ../Setup-on-Heroku
   ../Setup-on-OpenShift
